==> culibs-0.17.tar.bz2: culibs-0.17/cutext/chenc_conv.c <==
#include <cutext/fwd.h>
cutext_chenc_t cutext_chenc_from_cstr(char const *s)
{
switch (*s++) {
case 'U':
switch (*s++) {
case 'C':
switch (*s++) {
case 'S':
switch (*s++) {
case '-':
switch (*s++) {
case '2':
switch (*s++) {
case 0:
return cutext_chenc_ucs2;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_ucs2;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_ucs2le;
}
break;
}
break;
}
break;
case '4':
switch (*s++) {
case 0:
return cutext_chenc_ucs4;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_ucs4;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_ucs4le;
}
break;
}
break;
}
break;
}
break;
case '\342':
switch (*s++) {
case '\200':
switch (*s++) {
case '\220':
switch (*s++) {
case '2':
switch (*s++) {
case 0:
return cutext_chenc_ucs2;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_ucs2;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_ucs2le;
}
break;
}
break;
}
break;
case '4':
switch (*s++) {
case 0:
return cutext_chenc_ucs4;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_ucs4;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_ucs4le;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
case 'T':
switch (*s++) {
case 'F':
switch (*s++) {
case '-':
switch (*s++) {
case '1':
switch (*s++) {
case '6':
switch (*s++) {
case 0:
return cutext_chenc_utf16;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_utf16;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_utf16le;
}
break;
}
break;
}
break;
}
break;
case '8':
switch (*s++) {
case 0:
return cutext_chenc_utf8;
}
break;
}
break;
case '\342':
switch (*s++) {
case '\200':
switch (*s++) {
case '\220':
switch (*s++) {
case '1':
switch (*s++) {
case '6':
switch (*s++) {
case 0:
return cutext_chenc_utf16;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_utf16;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return cutext_chenc_utf16le;
}
break;
}
break;
}
break;
}
break;
case '8':
switch (*s++) {
case 0:
return cutext_chenc_utf8;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
case 'n':
switch (*s++) {
case 'o':
switch (*s++) {
case 'n':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_none;
}
break;
}
break;
}
break;
}
break;
case 'u':
switch (*s++) {
case 'c':
switch (*s++) {
case 's':
switch (*s++) {
case '-':
switch (*s++) {
case '2':
switch (*s++) {
case 0:
return cutext_chenc_ucs2;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_ucs2;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_ucs2le;
}
break;
}
break;
}
break;
case '4':
switch (*s++) {
case 0:
return cutext_chenc_ucs4;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_ucs4;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_ucs4le;
}
break;
}
break;
}
break;
}
break;
case '\342':
switch (*s++) {
case '\200':
switch (*s++) {
case '\220':
switch (*s++) {
case '2':
switch (*s++) {
case 0:
return cutext_chenc_ucs2;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_ucs2;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_ucs2le;
}
break;
}
break;
}
break;
case '4':
switch (*s++) {
case 0:
return cutext_chenc_ucs4;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_ucs4;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_ucs4le;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
case 'n':
switch (*s++) {
case 'k':
switch (*s++) {
case 'n':
switch (*s++) {
case 'o':
switch (*s++) {
case 'w':
switch (*s++) {
case 'n':
switch (*s++) {
case 0:
return cutext_chenc_unknown;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
case 't':
switch (*s++) {
case 'f':
switch (*s++) {
case '-':
switch (*s++) {
case '1':
switch (*s++) {
case '6':
switch (*s++) {
case 0:
return cutext_chenc_utf16;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_utf16;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_utf16le;
}
break;
}
break;
}
break;
}
break;
case '8':
switch (*s++) {
case 0:
return cutext_chenc_utf8;
}
break;
}
break;
case '\342':
switch (*s++) {
case '\200':
switch (*s++) {
case '\220':
switch (*s++) {
case '1':
switch (*s++) {
case '6':
switch (*s++) {
case 0:
return cutext_chenc_utf16;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_utf16;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return cutext_chenc_utf16le;
}
break;
}
break;
}
break;
}
break;
case '8':
switch (*s++) {
case 0:
return cutext_chenc_utf8;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
return cutext_chenc_unknown;
}

char const *cutext_chenc_to_cstr(cutext_chenc_t e)
{
switch(e) {
case cutext_chenc_ucs4le: return "UCS-4LE";
case cutext_chenc_ucs4: return "UCS-4";
case cutext_chenc_ucs2le: return "UCS-2LE";
case cutext_chenc_ucs2: return "UCS-2";
case cutext_chenc_utf16le: return "UTF-16LE";
case cutext_chenc_utf16: return "UTF-16";
case cutext_chenc_utf8: return "UTF-8";
case cutext_chenc_unknown: return "unknown";
case cutext_chenc_none: return "none";
default: return NULL;
}
}

==> culibs-0.24.tar.bz2: culibs-0.24/cutext/chenc_conv.c <==
#include <cutext/fwd.h>
cutext_encoding_t cutext_encoding_by_name(char const *s)
{
switch (*s++) {
case 'U':
switch (*s++) {
case 'C':
switch (*s++) {
case 'S':
switch (*s++) {
case '-':
switch (*s++) {
case '2':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2LE;
}
break;
}
break;
}
break;
case '4':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4LE;
}
break;
}
break;
}
break;
}
break;
case '\342':
switch (*s++) {
case '\200':
switch (*s++) {
case '\220':
switch (*s++) {
case '2':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2LE;
}
break;
}
break;
}
break;
case '4':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4LE;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
case 'T':
switch (*s++) {
case 'F':
switch (*s++) {
case '-':
switch (*s++) {
case '1':
switch (*s++) {
case '6':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16LE;
}
break;
}
break;
}
break;
}
break;
case '8':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF8;
}
break;
}
break;
case '\342':
switch (*s++) {
case '\200':
switch (*s++) {
case '\220':
switch (*s++) {
case '1':
switch (*s++) {
case '6':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16;
case 'B':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16;
}
break;
}
break;
case 'L':
switch (*s++) {
case 'E':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16LE;
}
break;
}
break;
}
break;
}
break;
case '8':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF8;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
case 'n':
switch (*s++) {
case 'o':
switch (*s++) {
case 'n':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_NONE;
}
break;
}
break;
}
break;
}
break;
case 'u':
switch (*s++) {
case 'c':
switch (*s++) {
case 's':
switch (*s++) {
case '-':
switch (*s++) {
case '2':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2LE;
}
break;
}
break;
}
break;
case '4':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4LE;
}
break;
}
break;
}
break;
}
break;
case '\342':
switch (*s++) {
case '\200':
switch (*s++) {
case '\220':
switch (*s++) {
case '2':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS2LE;
}
break;
}
break;
}
break;
case '4':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UCS4LE;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
case 'n':
switch (*s++) {
case 'k':
switch (*s++) {
case 'n':
switch (*s++) {
case 'o':
switch (*s++) {
case 'w':
switch (*s++) {
case 'n':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UNKNOWN;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
case 't':
switch (*s++) {
case 'f':
switch (*s++) {
case '-':
switch (*s++) {
case '1':
switch (*s++) {
case '6':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16LE;
}
break;
}
break;
}
break;
}
break;
case '8':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF8;
}
break;
}
break;
case '\342':
switch (*s++) {
case '\200':
switch (*s++) {
case '\220':
switch (*s++) {
case '1':
switch (*s++) {
case '6':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16;
case 'b':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16;
}
break;
}
break;
case 'l':
switch (*s++) {
case 'e':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF16LE;
}
break;
}
break;
}
break;
}
break;
case '8':
switch (*s++) {
case 0:
return CUTEXT_ENCODING_UTF8;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
break;
}
return CUTEXT_ENCODING_UNKNOWN;
}

char const *cutextP_encoding_name(cutext_encoding_t e)
{
switch(e) {
case CUTEXT_ENCODING_UCS4LE: return "UCS-4LE";
case CUTEXT_ENCODING_UCS4: return "UCS-4";
case CUTEXT_ENCODING_UCS2LE: return "UCS-2LE";
case CUTEXT_ENCODING_UCS2: return "UCS-2";
case CUTEXT_ENCODING_UTF16LE: return "UTF-16LE";
case CUTEXT_ENCODING_UTF16: return "UTF-16";
case CUTEXT_ENCODING_UTF8: return "UTF-8";
case CUTEXT_ENCODING_UNKNOWN: return "unknown";
case CUTEXT_ENCODING_NONE: return "none";
default: return NULL;
}
}
